==> monaco-vscode-debug-service-override-12.0.0.tgz: package/vscode/src/vs/workbench/contrib/debug/browser/replAccessibilityHelp.js <==

import { AccessibleViewType, AccessibleViewProviderId } from 'vscode/vscode/vs/platform/accessibility/browser/accessibleView';
import { ContextKeyExpr } from 'vscode/vscode/vs/platform/contextkey/common/contextkey';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { getReplView } from './repl.js';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';
import { AccessibilityVerbositySettingId } from 'vscode/vscode/vs/workbench/contrib/accessibility/browser/accessibilityConfiguration';
import { localize } from 'vscode/vscode/vs/nls';

class ReplAccessibilityHelp {
    constructor() {
        this.priority = 120;
        this.name = 'replHelp';
        this.when = ( ContextKeyExpr.equals('focusedView', 'workbench.panel.repl.view'));
        this.type = AccessibleViewType.Help;
    }
    getProvider(accessor) {
        const viewsService = accessor.get(IViewsService);
        const replView = getReplView(viewsService);
        if (!replView) {
            return undefined;
        }
        return ( new ReplAccessibilityHelpProvider(replView));
    }
}
class ReplAccessibilityHelpProvider extends Disposable {
    constructor(_replView) {
        super();
        this._replView = _replView;
        this.id = AccessibleViewProviderId.ReplHelp;
        this.verbositySettingKey = AccessibilityVerbositySettingId.Debug;
        this.options = { type: AccessibleViewType.Help };
        this._treeHadFocus = false;
        this._treeHadFocus = !!_replView.getFocusedElement();
    }
    onClose() {
        if (this._treeHadFocus) {
            return this._replView.focusTree();
        }
        this._replView.getReplInput().focus();
    }
    provideContent() {
        return [
            ( localize(
            5446,
            "The debug console is a Read-Eval-Print-Loop that allows you to evaluate expressions and run commands and can be focused with{0}.",
            '<keybinding:workbench.panel.repl.view.focus>'
        )),
            ( localize(
            5447,
            "The debug console output can be navigated to from the input field with the Focus Previous Widget command{0}.",
            '<keybinding:widgetNavigation.focusPrevious>'
        )),
            ( localize(
            5448,
            "The debug console input can be navigated to from the output with the Focus Next Widget command{0}.",
            '<keybinding:widgetNavigation.focusNext>'
        )),
            ( localize(
            5449,
            "The debug console output history can be navigated with the up and down arrow keys."
        )),
            ( localize(
            5450,
            "The Open Accessible View command{0} will allow character by character navigation of the console output.",
            '<keybinding:editor.action.accessibleView>'
        )),
            ( localize(
            5451,
            "The Show Run and Debug view command{0} will open the Run and Debug view and provides more information about debugging.",
            '<keybinding:workbench.view.debug>'
        )),
            ( localize(
            5452,
            "The Debug: Clear Console command{0} will clear the console output.",
            '<keybinding:workbench.debug.panel.action.clearReplAction>'
        )),
            ( localize(
            5453,
            "The setting `debug.expandLazyVariables` controls whether variables are evaluated automatically. This is enabled by default when using a screen reader."
        )),
        ].join('\n');
    }
}

export { ReplAccessibilityHelp };

==> monaco-vscode-debug-service-override-13.0.0.tgz: package/vscode/src/vs/workbench/contrib/debug/browser/replAccessibilityHelp.js <==

import { AccessibleViewType, AccessibleViewProviderId } from '@codingame/monaco-vscode-api/vscode/vs/platform/accessibility/browser/accessibleView';
import { ContextKeyExpr } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey';
import { Disposable } from '@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle';
import { getReplView } from './repl.js';
import { IViewsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/views/common/viewsService.service';
import { AccessibilityVerbositySettingId } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/accessibility/browser/accessibilityConfiguration';
import { localize } from '@codingame/monaco-vscode-api/vscode/vs/nls';

class ReplAccessibilityHelp {
    constructor() {
        this.priority = 120;
        this.name = 'replHelp';
        this.when = ( ContextKeyExpr.equals('focusedView', 'workbench.panel.repl.view'));
        this.type = AccessibleViewType.Help;
    }
    getProvider(accessor) {
        const viewsService = accessor.get(IViewsService);
        const replView = getReplView(viewsService);
        if (!replView) {
            return undefined;
        }
        return ( new ReplAccessibilityHelpProvider(replView));
    }
}
class ReplAccessibilityHelpProvider extends Disposable {
    constructor(_replView) {
        super();
        this._replView = _replView;
        this.id = AccessibleViewProviderId.ReplHelp;
        this.verbositySettingKey = AccessibilityVerbositySettingId.Debug;
        this.options = { type: AccessibleViewType.Help };
        this._treeHadFocus = false;
        this._treeHadFocus = !!_replView.getFocusedElement();
    }
    onClose() {
        if (this._treeHadFocus) {
            return this._replView.focusTree();
        }
        this._replView.getReplInput().focus();
    }
    provideContent() {
        return [
            ( localize(
            5446,
            "The debug console is a Read-Eval-Print-Loop that allows you to evaluate expressions and run commands and can be focused with{0}.",
            '<keybinding:workbench.panel.repl.view.focus>'
        )),
            ( localize(
            5447,
            "The debug console output can be navigated to from the input field with the Focus Previous Widget command{0}.",
            '<keybinding:widgetNavigation.focusPrevious>'
        )),
            ( localize(
            5448,
            "The debug console input can be navigated to from the output with the Focus Next Widget command{0}.",
            '<keybinding:widgetNavigation.focusNext>'
        )),
            ( localize(
            5449,
            "The debug console output history can be navigated with the up and down arrow keys."
        )),
            ( localize(
            5450,
            "The Open Accessible View command{0} will allow character by character navigation of the console output.",
            '<keybinding:editor.action.accessibleView>'
        )),
            ( localize(
            5451,
            "The Show Run and Debug view command{0} will open the Run and Debug view and provides more information about debugging.",
            '<keybinding:workbench.view.debug>'
        )),
            ( localize(
            5452,
            "The Debug: Clear Console command{0} will clear the console output.",
            '<keybinding:workbench.debug.panel.action.clearReplAction>'
        )),
            ( localize(
            5453,
            "The setting `debug.expandLazyVariables` controls whether variables are evaluated automatically. This is enabled by default when using a screen reader."
        )),
        ].join('\n');
    }
}

export { ReplAccessibilityHelp };
